Iau

Struct Iau 

pub struct Iau<T: TryRotationalElements>(/* private fields */);
IAU body-fixed reference frame derived from rotational elements.

Implementations

Source

impl<T> Iau<T>

pub fn new(body: T) -> Self

Creates an IAU frame for a body with known rotational elements.

Source

impl<T> Iau<T>

pub fn try_new(body: T) -> Result<Self, UndefinedOriginPropertyError>

Creates an IAU frame, returning an error if rotational elements are undefined.

pub fn body(&self) -> T
where T: Copy,

Returns the underlying body.

pub fn rotational_elements(&self, j2000: f64) -> (f64, f64, f64)

Returns the rotational elements (right ascension, declination, prime meridian) at the given Julian centuries since J2000.

pub fn rotational_element_rates(&self, j2000: f64) -> (f64, f64, f64)

Returns the time derivatives of the rotational elements.