Module nutation

Module nutation 

Nutation models. Module nutation exposes a function for calculating Earth nutation using a number of IAU nutation models.

Structs

Nutation
Nutation components with respect to some ecliptic of date.