TryRotation

Trait TryRotation 

pub trait TryRotation<Origin, Target, T>{
    type Error: Error + Send + Sync + 'static;

    // Required method
    fn try_rotation(
        &self,
        origin: Origin,
        target: Target,
        time: Time<T>,
    ) -> Result<Rotation, Self::Error>;
}
Computes the rotation from one reference frame to another at a given time.

Required Associated Types

type Error: Error + Send + Sync + 'static

The error type returned when the rotation cannot be computed.

Required Methods

fn try_rotation( &self, origin: Origin, target: Target, time: Time<T>, ) -> Result<Rotation, Self::Error>

Computes the rotation from origin to target at the given time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, O, Tg, P> TryRotation<O, Tg, T> for P

Blanket rotation between any two frames that know their route to ICRF.