Module traits

Module traits 

Core reference frame traits.

Structs

NonBodyFixedFrameError
The frame is not body-fixed.
NonQuasiInertialFrameError
The frame is not quasi-inertial.

Enums

FrameKey
Structural identity of a reference frame, used to detect when two frames — whether expressed concretely or as a Frame — are the same, without rotating.
UndefinedReferenceEllipsoidError
Error returned when a frame has no reference ellipsoid.

Traits

BodyFixed
Marker trait for body-fixed reference frames.
QuasiInertial
Marker trait for quasi-inertial reference frames.
ReferenceEllipsoid
A body-fixed frame with a conventional reference ellipsoid.
ReferenceFrame
A reference frame with a human-readable name and abbreviation.
TryBodyFixed
Fallible check for body-fixed frames (used by dynamic dispatch).
TryQuasiInertial
Fallible check for quasi-inertial frames (used by dynamic dispatch).
TryReferenceEllipsoid
Fallible accessor for a frame’s reference ellipsoid (used by dynamic dispatch).

Functions

frame_key
Returns the frame’s identity key, if it has one.