pub enum UndefinedReferenceEllipsoidError {
NotBodyFixed(NonBodyFixedFrameError),
UndefinedSpheroid(UndefinedOriginPropertyError),
}Expand description
Error returned when a frame has no reference ellipsoid.
Variants
NotBodyFixed(NonBodyFixedFrameError)
The frame is not body-fixed, so no datum is associated with it.
UndefinedSpheroid(UndefinedOriginPropertyError)
The frame’s origin has no spheroid, as for a triaxial body.