pub trait TryReferenceEllipsoid: TryBodyFixed {
// Required method
fn try_reference_ellipsoid(
&self,
) -> Result<Ellipsoid, UndefinedReferenceEllipsoidError>;
}Expand description
Fallible accessor for a frame’s reference ellipsoid (used by dynamic dispatch).
Required Methods
Sourcefn try_reference_ellipsoid(
&self,
) -> Result<Ellipsoid, UndefinedReferenceEllipsoidError>
fn try_reference_ellipsoid( &self, ) -> Result<Ellipsoid, UndefinedReferenceEllipsoidError>
Returns the reference ellipsoid conventionally paired with this frame, or an error if the frame is not body-fixed or its origin is not a spheroid.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".