IERS reference systems, conventions, and Earth orientation sub-models.
Modules
- cio
- Celestial Intermediate Origin locator. Module cio exposes functions for calculating the Celestial Intermediate Origin (CIO) locator, s.
- cip
- Celestial Intermediate Pole coordinates. Module cip exposes functions for calculating the position of the Celestial Intermediate Pole (CIP).
- earth_
rotation - Earth rotation angle and equation of the equinoxes. Module rotation_angle exposes functions for calculating the Earth Rotation Angle (ERA).
- ecliptic
- Obliquity of the ecliptic.
- fundamental
- Fundamental (Delaunay) arguments. Fundamental astronomical arguments according to various IAU conventions.
- nutation
- Nutation models. Module nutation exposes a function for calculating Earth nutation using a number of IAU nutation models.
- polar_
motion - Polar motion coordinates and matrices.
- precession
- Precession matrices and frame bias.
- tio
- Terrestrial Intermediate Origin locator. Module tio exposes functions for calculating the Terrestrial Intermediate Origin (TIO) locator, s’, which places the TIO on the equator of the Celestial Intermediate Pole (CIP).
Structs
- Corrections
- Earth orientation parameter corrections (δψ/δX, δε/δY).
- Iers1996
- IERS 1996 conventions.
- Iers2003
- IERS 2003 conventions, parameterised by IAU 2000 nutation model.
- Iers2010
- IERS 2010 conventions.
Enums
- Iau2000
Model - IAU 2000 nutation model variant.
- Reference
System - Dynamic dispatch enum for IERS convention systems.
Traits
- Iers
System - Sealed trait for IERS convention systems.