pub enum ReferenceSystem {
Iers1996,
Iers2003(Iau2000Model),
Iers2010,
}Expand description
Dynamic dispatch enum for IERS convention systems.
Variants
Iers1996
IERS 1996 conventions.
Iers2003(Iau2000Model)
IERS 2003 conventions with the given IAU 2000 model.
Iers2010
IERS 2010 conventions.
Implementations
Sourceimpl ReferenceSystem
impl ReferenceSystem
Sourcepub fn earth_rotation(
&self,
tt: Time<Tt>,
ut1: Time<Ut1>,
corr: Corrections,
) -> DMat3
pub fn earth_rotation( &self, tt: Time<Tt>, ut1: Time<Ut1>, corr: Corrections, ) -> DMat3
Returns the Earth rotation matrix for the given times and corrections.
Sourcepub fn greenwich_mean_sidereal_time(
&self,
tt: Time<Tt>,
ut1: Time<Ut1>,
) -> GreenwichMeanSiderealTime
pub fn greenwich_mean_sidereal_time( &self, tt: Time<Tt>, ut1: Time<Ut1>, ) -> GreenwichMeanSiderealTime
Computes Greenwich Mean Sidereal Time (GMST) for the active IERS convention.
Sourcepub fn greenwich_apparent_sidereal_time(
&self,
tt: Time<Tt>,
ut1: Time<Ut1>,
corr: Corrections,
) -> GreenwichApparentSiderealTime
pub fn greenwich_apparent_sidereal_time( &self, tt: Time<Tt>, ut1: Time<Ut1>, corr: Corrections, ) -> GreenwichApparentSiderealTime
Computes Greenwich Apparent Sidereal Time (GAST) for the active IERS convention.
Sourceimpl ReferenceSystem
impl ReferenceSystem
Sourcepub fn mean_obliquity(&self, time: Time<Tt>) -> MeanObliquity
pub fn mean_obliquity(&self, time: Time<Tt>) -> MeanObliquity
Returns the mean obliquity of the ecliptic for the given IERS convention.
Sourceimpl ReferenceSystem
impl ReferenceSystem
Sourcepub fn polar_motion_matrix(
&self,
time: Time<Tt>,
pole_coords: PoleCoords,
) -> DMat3
pub fn polar_motion_matrix( &self, time: Time<Tt>, pole_coords: PoleCoords, ) -> DMat3
Returns the polar motion rotation matrix for the given pole coordinates.
Sourceimpl ReferenceSystem
impl ReferenceSystem
Sourcepub fn precession(&self, time: Time<Tt>) -> PrecessionAngles
pub fn precession(&self, time: Time<Tt>) -> PrecessionAngles
Computes the precession angles for the active IERS convention.
Sourcepub fn bias_precession_matrix(&self, time: Time<Tt>) -> DMat3
pub fn bias_precession_matrix(&self, time: Time<Tt>) -> DMat3
Returns the rotation from ICRF to the Mean-of-Date (MOD) frame for the given IERS convention.
Sourcepub fn precession_matrix(&self, time: Time<Tt>) -> DMat3
pub fn precession_matrix(&self, time: Time<Tt>) -> DMat3
Returns the precession-only rotation from J2000 to the Mean-of-Date (MOD) frame.
Sourceimpl ReferenceSystem
impl ReferenceSystem
Sourcepub fn ecliptic_corrections(
&self,
corr: Corrections,
nut: Nutation,
epsa: MeanObliquity,
rpb: DMat3,
) -> Corrections
pub fn ecliptic_corrections( &self, corr: Corrections, nut: Nutation, epsa: MeanObliquity, rpb: DMat3, ) -> Corrections
Converts EOP corrections between ecliptic and equatorial representations.