Module rotations

Module rotations 

Rotation matrices, the rotations::TryRotation trait, and rotations::RotationProvider.

Modules

to_iau
IAU body-fixed frame rotation calculations.
to_icrf
Hub-based rotation composition through ICRF. Rotations between reference frames, composed through ICRF.

Structs

Rotation
A rotation matrix with its time derivative, for transforming position and velocity vectors.

Enums

RotationError
The source of a rotation error. A frame rotation could not be computed.

Traits

RotationProvider
Provides Earth orientation data and frame rotation methods for a given time scale.
TryRotation
Computes the rotation from one reference frame to another at a given time.