pub trait TryRotation<Origin, Target, T>{
type Error: Error + Send + Sync + 'static;
// Required method
fn try_rotation(
&self,
origin: Origin,
target: Target,
time: Time<T>,
) -> Result<Rotation, Self::Error>;
}Expand description
Computes the rotation from one reference frame to another at a given time.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<T, O, Tg, P> TryRotation<O, Tg, T> for Pwhere
T: ContinuousTimeScale + Copy,
O: ReferenceFrame + RotateToIcrf<T, P, Error = RotationError>,
Tg: ReferenceFrame + RotateToIcrf<T, P, Error = RotationError>,
Blanket rotation between any two frames that know their route to ICRF.
impl<T, O, Tg, P> TryRotation<O, Tg, T> for Pwhere
T: ContinuousTimeScale + Copy,
O: ReferenceFrame + RotateToIcrf<T, P, Error = RotationError>,
Tg: ReferenceFrame + RotateToIcrf<T, P, Error = RotationError>,
Blanket rotation between any two frames that know their route to ICRF.