Core reference frame traits.
Structs
- NonBody
Fixed Frame Error - The frame is not body-fixed.
- NonQuasi
Inertial Frame Error - The frame is not quasi-inertial.
Enums
- Frame
Key - Structural identity of a reference frame, used to detect when two frames —
whether expressed concretely or as a
Frame— are the same, without rotating. - Undefined
Reference Ellipsoid Error - Error returned when a frame has no reference ellipsoid.
Traits
- Body
Fixed - Marker trait for body-fixed reference frames.
- Quasi
Inertial - Marker trait for quasi-inertial reference frames.
- Reference
Ellipsoid - A body-fixed frame with a conventional reference ellipsoid.
- Reference
Frame - A reference frame with a human-readable name and abbreviation.
- TryBody
Fixed - Fallible check for body-fixed frames (used by dynamic dispatch).
- TryQuasi
Inertial - Fallible check for quasi-inertial frames (used by dynamic dispatch).
- TryReference
Ellipsoid - Fallible accessor for a frame’s reference ellipsoid (used by dynamic dispatch).
Functions
- frame_
key - Returns the frame’s identity key, if it has one.